@@ -1,7 +1,6 @@
 from balcony import BaseBalconyApp, BalconyAWS, get_rich_console
 from typer.main import Typer
 import typer
-from typing import Optional
 import jmespath
 import random
 import time
@@ -9,6 +8,7 @@ from rich.layout import Layout
 from rich.live import Live
 from rich.table import Table
 from rich.panel import Panel
+from typing import List, Set, Dict, Tuple, Optional, Union
 
 
 
@@ -25,9 +25,8 @@ class PriviledgeEscalationPreventer(BaseBalconyApp,
         pass
       
     def get_data(self, *args, **kwargs) -> dict:
-        service=kwargs.get('service')
         balcony = BalconyAWS()
-        service_node = balcony.get_service(service)
+        iam_service = balcony.get_service('iam')
         return {
             'read_only_function_count':'read_only_function_count',
             'resource_nodes': 'generated_resource_nodes'
@@ -39,15 +38,30 @@ class PriviledgeEscalationPreventer(BaseBalconyApp,
 
         @app.callback(invoke_without_command=True)
         def _command(
-            service: str = typer.Argument(None, show_default=False,help='AWS Service Name'),
-        ):
-            balcony = BalconyAWS()
-            available_services = balcony.get_available_service_node_names()
-            selected_service = random.choice(available_services)
+            patterns: Optional[List[str]] = typer.Option(None, "--pattern", '-p', show_default=False, help='UNIX pattern matching for generated parameters. Should be quoted. e.g. (-p "*prod-*")'),
 
+        ):
+            available_services = balcony.get_available_service_node_names()
+            balcony = BalconyAWS()
+            iam_service = balcony.get_service('iam')
+
+            iam_reader = iam_service.get_service_reader()
+            roles = iam_reader.read_operation('Role', 'GetRole', match_patterns=patterns)
+            # get roles
+            console.print(roles)
                     
         return app
                 
     
 
 
+"""
+select some roles to start with
+for each role:
+    create a policy for PrvEsc-PermissionBoundary, 
+    put-role-permissions-boundary
+
++ tf like plan and apply logic
+
+
+"""
\ No newline at end of file
